Documentation
¶
Index ¶
- Variables
- func RegisterQueryServer(s grpc1.Server, srv QueryServer)
- type Config
- func (*Config) Descriptor() ([]byte, []int)
- func (m *Config) GetGolangBindings() []*GolangBinding
- func (m *Config) GetModules() []*ModuleConfig
- func (m *Config) Marshal() (dAtA []byte, err error)
- func (m *Config) MarshalTo(dAtA []byte) (int, error)
- func (m *Config) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*Config) ProtoMessage()
- func (m *Config) Reset()
- func (m *Config) Size() (n int)
- func (m *Config) String() string
- func (m *Config) Unmarshal(dAtA []byte) error
- func (m *Config) XXX_DiscardUnknown()
- func (m *Config) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *Config) XXX_Merge(src proto.Message)
- func (m *Config) XXX_Size() int
- func (m *Config) XXX_Unmarshal(b []byte) error
- type GolangBinding
- func (*GolangBinding) Descriptor() ([]byte, []int)
- func (m *GolangBinding) GetImplementation() string
- func (m *GolangBinding) GetInterfaceType() string
- func (m *GolangBinding) Marshal() (dAtA []byte, err error)
- func (m *GolangBinding) MarshalTo(dAtA []byte) (int, error)
- func (m *GolangBinding) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*GolangBinding) ProtoMessage()
- func (m *GolangBinding) Reset()
- func (m *GolangBinding) Size() (n int)
- func (m *GolangBinding) String() string
- func (m *GolangBinding) Unmarshal(dAtA []byte) error
- func (m *GolangBinding) XXX_DiscardUnknown()
- func (m *GolangBinding) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GolangBinding) XXX_Merge(src proto.Message)
- func (m *GolangBinding) XXX_Size() int
- func (m *GolangBinding) XXX_Unmarshal(b []byte) error
- type MigrateFromInfo
- func (*MigrateFromInfo) Descriptor() ([]byte, []int)
- func (m *MigrateFromInfo) GetModule() string
- func (m *MigrateFromInfo) Marshal() (dAtA []byte, err error)
- func (m *MigrateFromInfo) MarshalTo(dAtA []byte) (int, error)
- func (m *MigrateFromInfo) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*MigrateFromInfo) ProtoMessage()
- func (m *MigrateFromInfo) Reset()
- func (m *MigrateFromInfo) Size() (n int)
- func (m *MigrateFromInfo) String() string
- func (m *MigrateFromInfo) Unmarshal(dAtA []byte) error
- func (m *MigrateFromInfo) XXX_DiscardUnknown()
- func (m *MigrateFromInfo) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *MigrateFromInfo) XXX_Merge(src proto.Message)
- func (m *MigrateFromInfo) XXX_Size() int
- func (m *MigrateFromInfo) XXX_Unmarshal(b []byte) error
- type ModuleConfig
- func (*ModuleConfig) Descriptor() ([]byte, []int)
- func (m *ModuleConfig) GetConfig() *any.Any
- func (m *ModuleConfig) GetGolangBindings() []*GolangBinding
- func (m *ModuleConfig) GetName() string
- func (m *ModuleConfig) Marshal() (dAtA []byte, err error)
- func (m *ModuleConfig) MarshalTo(dAtA []byte) (int, error)
- func (m *ModuleConfig) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*ModuleConfig) ProtoMessage()
- func (m *ModuleConfig) Reset()
- func (m *ModuleConfig) Size() (n int)
- func (m *ModuleConfig) String() string
- func (m *ModuleConfig) Unmarshal(dAtA []byte) error
- func (m *ModuleConfig) XXX_DiscardUnknown()
- func (m *ModuleConfig) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ModuleConfig) XXX_Merge(src proto.Message)
- func (m *ModuleConfig) XXX_Size() int
- func (m *ModuleConfig) XXX_Unmarshal(b []byte) error
- type ModuleDescriptor
- func (*ModuleDescriptor) Descriptor() ([]byte, []int)
- func (m *ModuleDescriptor) GetCanMigrateFrom() []*MigrateFromInfo
- func (m *ModuleDescriptor) GetGoImport() string
- func (m *ModuleDescriptor) GetUsePackage() []*PackageReference
- func (m *ModuleDescriptor) Marshal() (dAtA []byte, err error)
- func (m *ModuleDescriptor) MarshalTo(dAtA []byte) (int, error)
- func (m *ModuleDescriptor) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*ModuleDescriptor) ProtoMessage()
- func (m *ModuleDescriptor) Reset()
- func (m *ModuleDescriptor) Size() (n int)
- func (m *ModuleDescriptor) String() string
- func (m *ModuleDescriptor) Unmarshal(dAtA []byte) error
- func (m *ModuleDescriptor) XXX_DiscardUnknown()
- func (m *ModuleDescriptor) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ModuleDescriptor) XXX_Merge(src proto.Message)
- func (m *ModuleDescriptor) XXX_Size() int
- func (m *ModuleDescriptor) XXX_Unmarshal(b []byte) error
- type PackageReference
- func (*PackageReference) Descriptor() ([]byte, []int)
- func (m *PackageReference) GetName() string
- func (m *PackageReference) GetRevision() uint32
- func (m *PackageReference) Marshal() (dAtA []byte, err error)
- func (m *PackageReference) MarshalTo(dAtA []byte) (int, error)
- func (m *PackageReference) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*PackageReference) ProtoMessage()
- func (m *PackageReference) Reset()
- func (m *PackageReference) Size() (n int)
- func (m *PackageReference) String() string
- func (m *PackageReference) Unmarshal(dAtA []byte) error
- func (m *PackageReference) XXX_DiscardUnknown()
- func (m *PackageReference) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *PackageReference) XXX_Merge(src proto.Message)
- func (m *PackageReference) XXX_Size() int
- func (m *PackageReference) XXX_Unmarshal(b []byte) error
- type QueryClient
- type QueryConfigRequest
- func (*QueryConfigRequest) Descriptor() ([]byte, []int)
- func (m *QueryConfigRequest) Marshal() (dAtA []byte, err error)
- func (m *QueryConfigRequest) MarshalTo(dAtA []byte) (int, error)
- func (m *QueryConfigRequest) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*QueryConfigRequest) ProtoMessage()
- func (m *QueryConfigRequest) Reset()
- func (m *QueryConfigRequest) Size() (n int)
- func (m *QueryConfigRequest) String() string
- func (m *QueryConfigRequest) Unmarshal(dAtA []byte) error
- func (m *QueryConfigRequest) XXX_DiscardUnknown()
- func (m *QueryConfigRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *QueryConfigRequest) XXX_Merge(src proto.Message)
- func (m *QueryConfigRequest) XXX_Size() int
- func (m *QueryConfigRequest) XXX_Unmarshal(b []byte) error
- type QueryConfigResponse
- func (*QueryConfigResponse) Descriptor() ([]byte, []int)
- func (m *QueryConfigResponse) GetConfig() *Config
- func (m *QueryConfigResponse) Marshal() (dAtA []byte, err error)
- func (m *QueryConfigResponse) MarshalTo(dAtA []byte) (int, error)
- func (m *QueryConfigResponse) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*QueryConfigResponse) ProtoMessage()
- func (m *QueryConfigResponse) Reset()
- func (m *QueryConfigResponse) Size() (n int)
- func (m *QueryConfigResponse) String() string
- func (m *QueryConfigResponse) Unmarshal(dAtA []byte) error
- func (m *QueryConfigResponse) XXX_DiscardUnknown()
- func (m *QueryConfigResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *QueryConfigResponse) XXX_Merge(src proto.Message)
- func (m *QueryConfigResponse) XXX_Size() int
- func (m *QueryConfigResponse) XXX_Unmarshal(b []byte) error
- type QueryServer
- type UnimplementedQueryServer
Constants ¶
This section is empty.
Variables ¶
var ( ErrInvalidLengthConfig = fmt.Errorf("proto: negative length found during unmarshaling") ErrIntOverflowConfig = fmt.Errorf("proto: integer overflow") ErrUnexpectedEndOfGroupConfig = fmt.Errorf("proto: unexpected end of group") )
var ( ErrInvalidLengthModule = fmt.Errorf("proto: negative length found during unmarshaling") ErrIntOverflowModule = fmt.Errorf("proto: integer overflow") ErrUnexpectedEndOfGroupModule = fmt.Errorf("proto: unexpected end of group") )
var ( ErrInvalidLengthQuery = fmt.Errorf("proto: negative length found during unmarshaling") ErrIntOverflowQuery = fmt.Errorf("proto: integer overflow") ErrUnexpectedEndOfGroupQuery = fmt.Errorf("proto: unexpected end of group") )
var E_Module = &proto.ExtensionDesc{ ExtendedType: (*descriptorpb.MessageOptions)(nil), ExtensionType: (*ModuleDescriptor)(nil), Field: 57193479, Name: "cosmos.app.v1alpha1.module", Tag: "bytes,57193479,opt,name=module", Filename: "cosmos/app/v1alpha1/module.proto", }
var Query_serviceDesc = _Query_serviceDesc
Functions ¶
func RegisterQueryServer ¶
func RegisterQueryServer(s grpc1.Server, srv QueryServer)
Types ¶
type Config ¶
type Config struct {
// modules are the module configurations for the app.
Modules []*ModuleConfig `protobuf:"bytes,1,rep,name=modules,proto3" json:"modules,omitempty"`
// golang_bindings specifies explicit interface to implementation type bindings which
// depinject uses to resolve interface inputs to provider functions. The scope of this
// field's configuration is global (not module specific).
GolangBindings []*GolangBinding `protobuf:"bytes,2,rep,name=golang_bindings,json=golangBindings,proto3" json:"golang_bindings,omitempty"`
}
Config represents the configuration for a Cosmos SDK ABCI app. It is intended that all state machine logic including the version of baseapp and tx handlers (and possibly even Tendermint) that an app needs can be described in a config object. For compatibility, the framework should allow a mixture of declarative and imperative app wiring, however, apps that strive for the maximum ease of maintainability should be able to describe their state machine with a config object alone.
func (*Config) Descriptor ¶
func (*Config) GetGolangBindings ¶
func (m *Config) GetGolangBindings() []*GolangBinding
func (*Config) GetModules ¶
func (m *Config) GetModules() []*ModuleConfig
func (*Config) MarshalToSizedBuffer ¶
func (*Config) ProtoMessage ¶
func (*Config) ProtoMessage()
func (*Config) XXX_DiscardUnknown ¶
func (m *Config) XXX_DiscardUnknown()
func (*Config) XXX_Marshal ¶
func (*Config) XXX_Unmarshal ¶
type GolangBinding ¶
type GolangBinding struct {
// interface_type is the interface type which will be bound to a specific implementation type
InterfaceType string `protobuf:"bytes,1,opt,name=interface_type,json=interfaceType,proto3" json:"interface_type,omitempty"`
// implementation is the implementing type which will be supplied when an input of type interface is requested
Implementation string `protobuf:"bytes,2,opt,name=implementation,proto3" json:"implementation,omitempty"`
}
GolangBinding is an explicit interface type to implementing type binding for dependency injection.
func (*GolangBinding) Descriptor ¶
func (*GolangBinding) Descriptor() ([]byte, []int)
func (*GolangBinding) GetImplementation ¶
func (m *GolangBinding) GetImplementation() string
func (*GolangBinding) GetInterfaceType ¶
func (m *GolangBinding) GetInterfaceType() string
func (*GolangBinding) Marshal ¶
func (m *GolangBinding) Marshal() (dAtA []byte, err error)
func (*GolangBinding) MarshalToSizedBuffer ¶
func (m *GolangBinding) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*GolangBinding) ProtoMessage ¶
func (*GolangBinding) ProtoMessage()
func (*GolangBinding) Reset ¶
func (m *GolangBinding) Reset()
func (*GolangBinding) Size ¶
func (m *GolangBinding) Size() (n int)
func (*GolangBinding) String ¶
func (m *GolangBinding) String() string
func (*GolangBinding) Unmarshal ¶
func (m *GolangBinding) Unmarshal(dAtA []byte) error
func (*GolangBinding) XXX_DiscardUnknown ¶
func (m *GolangBinding) XXX_DiscardUnknown()
func (*GolangBinding) XXX_Marshal ¶
func (m *GolangBinding) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*GolangBinding) XXX_Merge ¶
func (m *GolangBinding) XXX_Merge(src proto.Message)
func (*GolangBinding) XXX_Size ¶
func (m *GolangBinding) XXX_Size() int
func (*GolangBinding) XXX_Unmarshal ¶
func (m *GolangBinding) XXX_Unmarshal(b []byte) error
type MigrateFromInfo ¶
type MigrateFromInfo struct {
// module is the fully-qualified protobuf name of the module config object
// for the previous module version, ex: "cosmos.group.module.v1.Module".
Module string `protobuf:"bytes,1,opt,name=module,proto3" json:"module,omitempty"`
}
MigrateFromInfo is information on a module version that a newer module can migrate from.
func (*MigrateFromInfo) Descriptor ¶
func (*MigrateFromInfo) Descriptor() ([]byte, []int)
func (*MigrateFromInfo) GetModule ¶
func (m *MigrateFromInfo) GetModule() string
func (*MigrateFromInfo) Marshal ¶
func (m *MigrateFromInfo) Marshal() (dAtA []byte, err error)
func (*MigrateFromInfo) MarshalToSizedBuffer ¶
func (m *MigrateFromInfo) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*MigrateFromInfo) ProtoMessage ¶
func (*MigrateFromInfo) ProtoMessage()
func (*MigrateFromInfo) Reset ¶
func (m *MigrateFromInfo) Reset()
func (*MigrateFromInfo) Size ¶
func (m *MigrateFromInfo) Size() (n int)
func (*MigrateFromInfo) String ¶
func (m *MigrateFromInfo) String() string
func (*MigrateFromInfo) Unmarshal ¶
func (m *MigrateFromInfo) Unmarshal(dAtA []byte) error
func (*MigrateFromInfo) XXX_DiscardUnknown ¶
func (m *MigrateFromInfo) XXX_DiscardUnknown()
func (*MigrateFromInfo) XXX_Marshal ¶
func (m *MigrateFromInfo) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*MigrateFromInfo) XXX_Merge ¶
func (m *MigrateFromInfo) XXX_Merge(src proto.Message)
func (*MigrateFromInfo) XXX_Size ¶
func (m *MigrateFromInfo) XXX_Size() int
func (*MigrateFromInfo) XXX_Unmarshal ¶
func (m *MigrateFromInfo) XXX_Unmarshal(b []byte) error
type ModuleConfig ¶
type ModuleConfig struct {
// name is the unique name of the module within the app. It should be a name
// that persists between different versions of a module so that modules
// can be smoothly upgraded to new versions.
//
// For example, for the module cosmos.bank.module.v1.Module, we may chose
// to simply name the module "bank" in the app. When we upgrade to
// cosmos.bank.module.v2.Module, the app-specific name "bank" stays the same
// and the framework knows that the v2 module should receive all the same state
// that the v1 module had. Note: modules should provide info on which versions
// they can migrate from in the ModuleDescriptor.can_migration_from field.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// config is the config object for the module. Module config messages should
// define a ModuleDescriptor using the cosmos.app.v1alpha1.is_module extension.
Config *any.Any `protobuf:"bytes,2,opt,name=config,proto3" json:"config,omitempty"`
// golang_bindings specifies explicit interface to implementation type bindings which
// depinject uses to resolve interface inputs to provider functions. The scope of this
// field's configuration is module specific.
GolangBindings []*GolangBinding `protobuf:"bytes,3,rep,name=golang_bindings,json=golangBindings,proto3" json:"golang_bindings,omitempty"`
}
ModuleConfig is a module configuration for an app.
func (*ModuleConfig) Descriptor ¶
func (*ModuleConfig) Descriptor() ([]byte, []int)
func (*ModuleConfig) GetConfig ¶
func (m *ModuleConfig) GetConfig() *any.Any
func (*ModuleConfig) GetGolangBindings ¶
func (m *ModuleConfig) GetGolangBindings() []*GolangBinding
func (*ModuleConfig) GetName ¶
func (m *ModuleConfig) GetName() string
func (*ModuleConfig) Marshal ¶
func (m *ModuleConfig) Marshal() (dAtA []byte, err error)
func (*ModuleConfig) MarshalToSizedBuffer ¶
func (m *ModuleConfig) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*ModuleConfig) ProtoMessage ¶
func (*ModuleConfig) ProtoMessage()
func (*ModuleConfig) Reset ¶
func (m *ModuleConfig) Reset()
func (*ModuleConfig) Size ¶
func (m *ModuleConfig) Size() (n int)
func (*ModuleConfig) String ¶
func (m *ModuleConfig) String() string
func (*ModuleConfig) Unmarshal ¶
func (m *ModuleConfig) Unmarshal(dAtA []byte) error
func (*ModuleConfig) XXX_DiscardUnknown ¶
func (m *ModuleConfig) XXX_DiscardUnknown()
func (*ModuleConfig) XXX_Marshal ¶
func (m *ModuleConfig) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ModuleConfig) XXX_Merge ¶
func (m *ModuleConfig) XXX_Merge(src proto.Message)
func (*ModuleConfig) XXX_Size ¶
func (m *ModuleConfig) XXX_Size() int
func (*ModuleConfig) XXX_Unmarshal ¶
func (m *ModuleConfig) XXX_Unmarshal(b []byte) error
type ModuleDescriptor ¶
type ModuleDescriptor struct {
// go_import names the package that should be imported by an app to load the
// module in the runtime module registry. It is required to make debugging
// of configuration errors easier for users.
GoImport string `protobuf:"bytes,1,opt,name=go_import,json=goImport,proto3" json:"go_import,omitempty"`
// use_package refers to a protobuf package that this module
// uses and exposes to the world. In an app, only one module should "use"
// or own a single protobuf package. It is assumed that the module uses
// all of the .proto files in a single package.
UsePackage []*PackageReference `protobuf:"bytes,2,rep,name=use_package,json=usePackage,proto3" json:"use_package,omitempty"`
// can_migrate_from defines which module versions this module can migrate
// state from. The framework will check that one module version is able to
// migrate from a previous module version before attempting to update its
// config. It is assumed that modules can transitively migrate from earlier
// versions. For instance if v3 declares it can migrate from v2, and v2
// declares it can migrate from v1, the framework knows how to migrate
// from v1 to v3, assuming all 3 module versions are registered at runtime.
CanMigrateFrom []*MigrateFromInfo `protobuf:"bytes,3,rep,name=can_migrate_from,json=canMigrateFrom,proto3" json:"can_migrate_from,omitempty"`
}
ModuleDescriptor describes an app module.
func (*ModuleDescriptor) Descriptor ¶
func (*ModuleDescriptor) Descriptor() ([]byte, []int)
func (*ModuleDescriptor) GetCanMigrateFrom ¶
func (m *ModuleDescriptor) GetCanMigrateFrom() []*MigrateFromInfo
func (*ModuleDescriptor) GetGoImport ¶
func (m *ModuleDescriptor) GetGoImport() string
func (*ModuleDescriptor) GetUsePackage ¶
func (m *ModuleDescriptor) GetUsePackage() []*PackageReference
func (*ModuleDescriptor) Marshal ¶
func (m *ModuleDescriptor) Marshal() (dAtA []byte, err error)
func (*ModuleDescriptor) MarshalToSizedBuffer ¶
func (m *ModuleDescriptor) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*ModuleDescriptor) ProtoMessage ¶
func (*ModuleDescriptor) ProtoMessage()
func (*ModuleDescriptor) Reset ¶
func (m *ModuleDescriptor) Reset()
func (*ModuleDescriptor) Size ¶
func (m *ModuleDescriptor) Size() (n int)
func (*ModuleDescriptor) String ¶
func (m *ModuleDescriptor) String() string
func (*ModuleDescriptor) Unmarshal ¶
func (m *ModuleDescriptor) Unmarshal(dAtA []byte) error
func (*ModuleDescriptor) XXX_DiscardUnknown ¶
func (m *ModuleDescriptor) XXX_DiscardUnknown()
func (*ModuleDescriptor) XXX_Marshal ¶
func (m *ModuleDescriptor) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ModuleDescriptor) XXX_Merge ¶
func (m *ModuleDescriptor) XXX_Merge(src proto.Message)
func (*ModuleDescriptor) XXX_Size ¶
func (m *ModuleDescriptor) XXX_Size() int
func (*ModuleDescriptor) XXX_Unmarshal ¶
func (m *ModuleDescriptor) XXX_Unmarshal(b []byte) error
type PackageReference ¶
type PackageReference struct {
// name is the fully-qualified name of the package.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// revision is the optional revision of the package that is being used.
// Protobuf packages used in Cosmos should generally have a major version
// as the last part of the package name, ex. foo.bar.baz.v1.
// The revision of a package can be thought of as the minor version of a
// package which has additional backwards compatible definitions that weren't
// present in a previous version.
//
// A package should indicate its revision with a source code comment
// above the package declaration in one of its files containing the
// text "Revision N" where N is an integer revision. All packages start
// at revision 0 the first time they are released in a module.
//
// When a new version of a module is released and items are added to existing
// .proto files, these definitions should contain comments of the form
// "Since: Revision N" where N is an integer revision.
//
// When the module runtime starts up, it will check the pinned proto
// image and panic if there are runtime protobuf definitions that are not
// in the pinned descriptor which do not have
// a "Since Revision N" comment or have a "Since Revision N" comment where
// N is <= to the revision specified here. This indicates that the protobuf
// files have been updated, but the pinned file descriptor hasn't.
//
// If there are items in the pinned file descriptor with a revision
// greater than the value indicated here, this will also cause a panic
// as it may mean that the pinned descriptor for a legacy module has been
// improperly updated or that there is some other versioning discrepancy.
// Runtime protobuf definitions will also be checked for compatibility
// with pinned file descriptors to make sure there are no incompatible changes.
//
// This behavior ensures that:
// - pinned proto images are up-to-date
// - protobuf files are carefully annotated with revision comments which
// are important good client UX
// - protobuf files are changed in backwards and forwards compatible ways
Revision uint32 `protobuf:"varint,2,opt,name=revision,proto3" json:"revision,omitempty"`
}
PackageReference is a reference to a protobuf package used by a module.
func (*PackageReference) Descriptor ¶
func (*PackageReference) Descriptor() ([]byte, []int)
func (*PackageReference) GetName ¶
func (m *PackageReference) GetName() string
func (*PackageReference) GetRevision ¶
func (m *PackageReference) GetRevision() uint32
func (*PackageReference) Marshal ¶
func (m *PackageReference) Marshal() (dAtA []byte, err error)
func (*PackageReference) MarshalToSizedBuffer ¶
func (m *PackageReference) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*PackageReference) ProtoMessage ¶
func (*PackageReference) ProtoMessage()
func (*PackageReference) Reset ¶
func (m *PackageReference) Reset()
func (*PackageReference) Size ¶
func (m *PackageReference) Size() (n int)
func (*PackageReference) String ¶
func (m *PackageReference) String() string
func (*PackageReference) Unmarshal ¶
func (m *PackageReference) Unmarshal(dAtA []byte) error
func (*PackageReference) XXX_DiscardUnknown ¶
func (m *PackageReference) XXX_DiscardUnknown()
func (*PackageReference) XXX_Marshal ¶
func (m *PackageReference) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*PackageReference) XXX_Merge ¶
func (m *PackageReference) XXX_Merge(src proto.Message)
func (*PackageReference) XXX_Size ¶
func (m *PackageReference) XXX_Size() int
func (*PackageReference) XXX_Unmarshal ¶
func (m *PackageReference) XXX_Unmarshal(b []byte) error
type QueryClient ¶
type QueryClient interface {
// Config returns the current app config.
Config(ctx context.Context, in *QueryConfigRequest, opts ...grpc.CallOption) (*QueryConfigResponse, error)
}
QueryClient is the client API for Query service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewQueryClient ¶
func NewQueryClient(cc grpc1.ClientConn) QueryClient
type QueryConfigRequest ¶
type QueryConfigRequest struct {
}
QueryConfigRequest is the Query/Config request type.
func (*QueryConfigRequest) Descriptor ¶
func (*QueryConfigRequest) Descriptor() ([]byte, []int)
func (*QueryConfigRequest) Marshal ¶
func (m *QueryConfigRequest) Marshal() (dAtA []byte, err error)
func (*QueryConfigRequest) MarshalTo ¶
func (m *QueryConfigRequest) MarshalTo(dAtA []byte) (int, error)
func (*QueryConfigRequest) MarshalToSizedBuffer ¶
func (m *QueryConfigRequest) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*QueryConfigRequest) ProtoMessage ¶
func (*QueryConfigRequest) ProtoMessage()
func (*QueryConfigRequest) Reset ¶
func (m *QueryConfigRequest) Reset()
func (*QueryConfigRequest) Size ¶
func (m *QueryConfigRequest) Size() (n int)
func (*QueryConfigRequest) String ¶
func (m *QueryConfigRequest) String() string
func (*QueryConfigRequest) Unmarshal ¶
func (m *QueryConfigRequest) Unmarshal(dAtA []byte) error
func (*QueryConfigRequest) XXX_DiscardUnknown ¶
func (m *QueryConfigRequest) XXX_DiscardUnknown()
func (*QueryConfigRequest) XXX_Marshal ¶
func (m *QueryConfigRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*QueryConfigRequest) XXX_Merge ¶
func (m *QueryConfigRequest) XXX_Merge(src proto.Message)
func (*QueryConfigRequest) XXX_Size ¶
func (m *QueryConfigRequest) XXX_Size() int
func (*QueryConfigRequest) XXX_Unmarshal ¶
func (m *QueryConfigRequest) XXX_Unmarshal(b []byte) error
type QueryConfigResponse ¶
type QueryConfigResponse struct {
// config is the current app config.
Config *Config `protobuf:"bytes,1,opt,name=config,proto3" json:"config,omitempty"`
}
QueryConfigResponse is the Query/Config response type.
func (*QueryConfigResponse) Descriptor ¶
func (*QueryConfigResponse) Descriptor() ([]byte, []int)
func (*QueryConfigResponse) GetConfig ¶
func (m *QueryConfigResponse) GetConfig() *Config
func (*QueryConfigResponse) Marshal ¶
func (m *QueryConfigResponse) Marshal() (dAtA []byte, err error)
func (*QueryConfigResponse) MarshalTo ¶
func (m *QueryConfigResponse) MarshalTo(dAtA []byte) (int, error)
func (*QueryConfigResponse) MarshalToSizedBuffer ¶
func (m *QueryConfigResponse) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*QueryConfigResponse) ProtoMessage ¶
func (*QueryConfigResponse) ProtoMessage()
func (*QueryConfigResponse) Reset ¶
func (m *QueryConfigResponse) Reset()
func (*QueryConfigResponse) Size ¶
func (m *QueryConfigResponse) Size() (n int)
func (*QueryConfigResponse) String ¶
func (m *QueryConfigResponse) String() string
func (*QueryConfigResponse) Unmarshal ¶
func (m *QueryConfigResponse) Unmarshal(dAtA []byte) error
func (*QueryConfigResponse) XXX_DiscardUnknown ¶
func (m *QueryConfigResponse) XXX_DiscardUnknown()
func (*QueryConfigResponse) XXX_Marshal ¶
func (m *QueryConfigResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*QueryConfigResponse) XXX_Merge ¶
func (m *QueryConfigResponse) XXX_Merge(src proto.Message)
func (*QueryConfigResponse) XXX_Size ¶
func (m *QueryConfigResponse) XXX_Size() int
func (*QueryConfigResponse) XXX_Unmarshal ¶
func (m *QueryConfigResponse) XXX_Unmarshal(b []byte) error
type QueryServer ¶
type QueryServer interface {
// Config returns the current app config.
Config(context.Context, *QueryConfigRequest) (*QueryConfigResponse, error)
}
QueryServer is the server API for Query service.
type UnimplementedQueryServer ¶
type UnimplementedQueryServer struct {
}
UnimplementedQueryServer can be embedded to have forward compatible implementations.
func (*UnimplementedQueryServer) Config ¶
func (*UnimplementedQueryServer) Config(ctx context.Context, req *QueryConfigRequest) (*QueryConfigResponse, error)